@@ -161,14 +161,6 @@ func (ti *boolType) NomsKind() types.NomsKind {
 	return types.BoolKind
 }
 
-// ParseValue implements TypeInfo interface.
-func (ti *boolType) ParseValue(ctx context.Context, vrw types.ValueReadWriter, str *string) (types.Value, error) {
-	if str == nil || *str == "" {
-		return types.NullValue, nil
-	}
-	return ti.ConvertValueToNomsValue(context.Background(), nil, *str)
-}
-
 // Promote implements TypeInfo interface.
 func (ti *boolType) Promote() TypeInfo {
 	return ti
@@ -200,7 +192,19 @@ func boolTypeConverter(ctx context.Context, src *boolType, destTi TypeInfo) (tc
 			}
 		}, true, nil
 	case *blobStringType:
-		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
+		return func(ctx context.Context, vrw types.ValueReadWriter, v types.Value) (types.Value, error) {
+			if v == nil || v == types.NullValue {
+				return types.NullValue, nil
+			}
+			val := v.(types.Bool)
+			var newVal int
+			if val {
+				newVal = 1
+			} else {
+				newVal = 0
+			}
+			return dest.ConvertValueToNomsValue(ctx, vrw, newVal)
+		}, true, nil
 	case *boolType:
 		return identityTypeConverter, false, nil
 	case *datetimeType:
@@ -212,7 +216,19 @@ func boolTypeConverter(ctx context.Context, src *boolType, destTi TypeInfo) (tc
 	case *floatType:
 		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
 	case *inlineBlobType:
-		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
+		return func(ctx context.Context, vrw types.ValueReadWriter, v types.Value) (types.Value, error) {
+			if v == nil || v == types.NullValue {
+				return types.NullValue, nil
+			}
+			val := v.(types.Bool)
+			var newVal int
+			if val {
+				newVal = 1
+			} else {
+				newVal = 0
+			}
+			return dest.ConvertValueToNomsValue(ctx, vrw, newVal)
+		}, true, nil
 	case *jsonType:
 		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
 	case *intType:
@@ -226,9 +242,33 @@ func boolTypeConverter(ctx context.Context, src *boolType, destTi TypeInfo) (tc
 	case *uuidType:
 		return nil, false, IncompatibleTypeConversion.New(src.String(), destTi.String())
 	case *varBinaryType:
-		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
+		return func(ctx context.Context, vrw types.ValueReadWriter, v types.Value) (types.Value, error) {
+			if v == nil || v == types.NullValue {
+				return types.NullValue, nil
+			}
+			val := v.(types.Bool)
+			var newVal int
+			if val {
+				newVal = 1
+			} else {
+				newVal = 0
+			}
+			return dest.ConvertValueToNomsValue(ctx, vrw, newVal)
+		}, true, nil
 	case *varStringType:
-		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
+		return func(ctx context.Context, vrw types.ValueReadWriter, v types.Value) (types.Value, error) {
+			if v == nil || v == types.NullValue {
+				return types.NullValue, nil
+			}
+			val := v.(types.Bool)
+			var newVal int
+			if val {
+				newVal = 1
+			} else {
+				newVal = 0
+			}
+			return dest.ConvertValueToNomsValue(ctx, vrw, newVal)
+		}, true, nil
 	case *yearType:
 		return wrapConvertValueToNomsValue(dest.ConvertValueToNomsValue)
 	default:
