@@ -135,14 +135,6 @@ func (ti *jsonType) NomsKind() types.NomsKind {
 	return types.JSONKind
 }
 
-// ParseValue implements TypeInfo interface.
-func (ti *jsonType) ParseValue(ctx context.Context, vrw types.ValueReadWriter, str *string) (types.Value, error) {
-	if str == nil {
-		return types.NullValue, nil
-	}
-	return ti.ConvertValueToNomsValue(ctx, vrw, *str)
-}
-
 // Promote implements TypeInfo interface.
 func (ti *jsonType) Promote() TypeInfo {
 	return &jsonType{ti.jsonType.Promote().(sql.JsonType)}
