@@ -123,18 +123,6 @@ func (ti *uuidType) NomsKind() types.NomsKind {
 	return types.UUIDKind
 }
 
-// ParseValue implements TypeInfo interface.
-func (ti *uuidType) ParseValue(ctx context.Context, vrw types.ValueReadWriter, str *string) (types.Value, error) {
-	if str == nil || *str == "" {
-		return types.NullValue, nil
-	}
-	uuidVal, err := uuid.Parse(*str)
-	if err != nil {
-		return nil, err
-	}
-	return types.UUID(uuidVal), nil
-}
-
 // Promote implements TypeInfo interface.
 func (ti *uuidType) Promote() TypeInfo {
 	return ti
