@@ -21,7 +21,6 @@ import (
 	"io"
 
 	"github.com/dolthub/go-mysql-server/sql"
-	"github.com/dolthub/go-mysql-server/sql/parse"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/diff"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
@@ -117,16 +116,9 @@ func NewDiffTable(ctx *sql.Context, tblName string, ddb *doltdb.DoltDB, root *do
 		return nil, err
 	}
 
-	// parses to literal, no need to pass through analyzer
-	defaultVal, err := parse.StringToColumnDefaultValue(ctx, fmt.Sprintf(`"%s"`, diffTypeModified))
-	if err != nil {
-		return nil, err
-	}
-
 	sqlSch.Schema = append(sqlSch.Schema, &sql.Column{
 		Name:     diffTypeColName,
 		Type:     sql.Text,
-		Default:  defaultVal,
 		Nullable: false,
 		Source:   diffTblName,
 	})
