@@ -25,6 +25,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
+	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb/durable"
 	"github.com/dolthub/dolt/go/libraries/doltcore/dtestutils"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/ref"
@@ -322,7 +323,7 @@ func GetAllRows(root *doltdb.RootValue, tableName string) ([]row.Row, error) {
 		return nil, err
 	}
 
-	rowData, err := table.GetRowData(ctx)
+	rowData, err := table.GetNomsRowData(ctx)
 
 	if err != nil {
 		return nil, err
@@ -512,7 +513,7 @@ func UpdateTables(t *testing.T, ctx context.Context, root *doltdb.RootValue, tbl
 		var rowData types.Map
 		if updates.NewRowData == nil {
 			if ok {
-				rowData, err = tbl.GetRowData(ctx)
+				rowData, err = tbl.GetNomsRowData(ctx)
 				require.NoError(t, err)
 			} else {
 				rowData, err = types.NewMap(ctx, root.VRW())
@@ -533,12 +534,13 @@ func UpdateTables(t *testing.T, ctx context.Context, root *doltdb.RootValue, tbl
 			require.NoError(t, err)
 		}
 
-		indexData, err := types.NewMap(ctx, root.VRW())
+		var indexData durable.IndexSet
 		require.NoError(t, err)
 		if tbl != nil {
 			indexData, err = tbl.GetIndexData(ctx)
 			require.NoError(t, err)
 		}
+
 		tbl, err = doltdb.NewTable(ctx, root.VRW(), sch, rowData, indexData, nil)
 		require.NoError(t, err)
 
